Installation
============

We currently support Python 3.5 & Python 3.6. For installation, there
are two alternatives:

1. Clone the repository ``https://github.com/IBCNServices/GENDIS.git``
   and run ``(python3 -m) pip -r install requirements.txt``
2. GENDIS is hosted on PyPi. You can just run
   ``(python3 -m) pip install gendis`` to add gendis to your
   dist-packages (you can use it from everywhere).